********
Overview
********

Welcome to the project. We're excited you decided to improve Oríon!

Hopefully, by then you should be familiar with our `contribution guide <https://github.com/Epistimio/orion/blob/master/CONTRIBUTING.md>`_ and `code of conduct <https://github.com/Epistimio/orion/blob/master/CODE_OF_CONDUCT.md>`_.
The documentation for developers is organized in the following, easy to read, sections:

* :doc:`Getting Started <installing>`. Installing the development environment
* :doc:`Conventions <standards>`. Get familiar with the project's standards and guidelines
* :doc:`Testing <testing>`. Implementing your changes and how to test your code
* :doc:`Documenting <documenting>`. Documenting your changes and updating the documentation
* :doc:`Continuous Integration <ci>`. Get familiar with our continuous integration setup
* :doc:`Releasing a new version <release>`. How to create and ship a new release

When you're done, don't forget to `rebase <https://www.atlassian.com/git/tutorials/rewriting-history/git-rebase>`_
your changes to the latest version of the *develop* branch of https://github.com/Epistimio/orion.
Then, submit your `pull request <https://github.com/epistimio/orion/pulls>`_ and ask for a review when the build is passing in the CI.

If you have any question or suggestion feel free to reach out to us by email or by `opening an issue <https://github.com/Epistimio/orion/issues>`_.
